@@ -1,6 +1,6 @@
 #!/usr/bin/python
 #
-# Copyright 2018-2020 Polyaxon, Inc.
+# Copyright 2018-2021 Polyaxon, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -22,6 +22,7 @@ import polyaxon_sdk
 
 from kubernetes.client.rest import ApiException
 
+from polyaxon import settings
 from polyaxon.agents import converter
 from polyaxon.agents.spawners.spawner import Spawner
 from polyaxon.client import PolyaxonClient
@@ -29,19 +30,52 @@ from polyaxon.env_vars.getters import get_run_info
 from polyaxon.exceptions import PolypodException
 from polyaxon.lifecycle import V1StatusCondition, V1Statuses
 from polyaxon.logger import logger
+from polyaxon.schemas.cli.checks_config import ChecksConfig
+from polyaxon.utils.tz_utils import now
 from polyaxon.utils.workers_utils import exit_context, get_pool_workers, get_wait
 
 
 class BaseAgent:
+    HEALTH_FILE = "/tmp/.healthz"
+
     def __init__(self, sleep_interval=None):
         self.sleep_interval = sleep_interval
         self.spawner = Spawner()
         self.client = PolyaxonClient()
         self._graceful_shutdown = False
+        self.content = settings.AGENT_CONFIG.to_dict(dump=True)
+
+    def get_info(self) -> polyaxon_sdk.V1Agent:
+        raise NotImplementedError
 
     def get_state(self) -> polyaxon_sdk.V1AgentStateResponse:
         raise NotImplementedError
 
+    def sync_compatible_updates(self, compatible_updates: Dict):
+        raise NotImplementedError
+
+    @classmethod
+    def get_healthz_config(cls):
+        try:
+            return ChecksConfig.read(cls.HEALTH_FILE, config_type=".json")
+        except:
+            return
+
+    @classmethod
+    def ping(cls):
+        ChecksConfig.init_file(cls.HEALTH_FILE)
+        config = cls.get_healthz_config()
+        if config:
+            config.last_check = now()
+            config.write(cls.HEALTH_FILE)
+
+    @classmethod
+    def pong(cls, interval: int = 15) -> bool:
+        config = cls.get_healthz_config()
+        if not config:
+            return False
+        return not config.should_check(interval=interval)
+
     def start(self) -> None:
         try:
             with exit_context() as exit_event:
@@ -58,7 +92,8 @@ class BaseAgent:
                             self.end()
                             return
                         if agent_state.state.full:
-                            index = 0
+                            index = 2
+                        self.ping()
                         timeout = self.sleep_interval or get_wait(index)
                         logger.info("Sleeping for {} seconds".format(timeout))
         finally:
@@ -71,6 +106,8 @@ class BaseAgent:
     def process(self, pool: "ThreadPoolExecutor") -> polyaxon_sdk.V1AgentStateResponse:
         try:
             agent_state = self.get_state()
+            if agent_state.compatible_updates:
+                self.sync_compatible_updates(agent_state.compatible_updates)
 
             if agent_state:
                 logger.info("Starting runs submission process.")
@@ -79,12 +116,22 @@ class BaseAgent:
                 return polyaxon_sdk.V1AgentStateResponse()
 
             state = agent_state.state
+            for run_data in state.schedules or []:
+                pool.submit(self.submit_run, run_data)
             for run_data in state.queued or []:
-                pool.submit(self.create_run, run_data)
+                pool.submit(self.submit_run, run_data)
             for run_data in state.stopping or []:
                 pool.submit(self.stop_run, run_data)
             for run_data in state.apply or []:
                 pool.submit(self.apply_run, run_data)
+            for run_data in state.deleting or []:
+                pool.submit(self.delete_run, run_data)
+            for run_data in state.hooks or []:
+                pool.submit(self.make_and_create_run, run_data)
+            for run_data in state.watchdogs or []:
+                pool.submit(self.make_and_create_run, run_data)
+            for run_data in state.tuners or []:
+                pool.submit(self.make_and_create_run, run_data, True)
             return agent_state
         except Exception as exc:
             logger.error(exc)
@@ -105,7 +152,7 @@ class BaseAgent:
             run_project=run_project,
             run_uuid=run_uuid,
             status=V1Statuses.FAILED,
-            reason="PolyaxonAgentRunActionFailed",
+            reason="AgentLogger",
             message=message,
         )
         logger.warning(message)
@@ -117,7 +164,7 @@ class BaseAgent:
             run_project=run_project,
             run_uuid=run_uuid,
             status=V1Statuses.STOPPED,
-            reason="PolyaxonAgentRunActionStopped",
+            reason="AgentLogger",
             message=message,
         )
         logger.warning(message)
@@ -131,7 +178,7 @@ class BaseAgent:
             run_project=run_project,
             run_uuid=run_uuid,
             status=V1Statuses.SCHEDULED,
-            reason="PolyaxonAgentRunActionScheduled",
+            reason="AgentLogger",
             message=message,
         )
         logger.info(message)
@@ -143,7 +190,7 @@ class BaseAgent:
             run_project=run_project,
             run_uuid=run_uuid,
             status=V1Statuses.RUNNING,
-            reason="PolyaxonAgentRunActionRunning",
+            reason="AgentLogger",
             message=message,
         )
         logger.info(message)
@@ -170,17 +217,49 @@ class BaseAgent:
 
     def clean_run(self, run_uuid: str, run_kind: str):
         try:
+            self.spawner.clean(run_uuid=run_uuid, run_kind=run_kind)
             self.spawner.stop(run_uuid=run_uuid, run_kind=run_kind)
         except ApiException as e:
             if e.status == 404:
-                logger.debug("Run does not exist.")
+                logger.info("Run does not exist.")
         except Exception as e:
-            logger.debug(
+            logger.info(
                 "Run could not be cleaned: {}\n{}".format(
                     repr(e), traceback.format_exc()
                 )
             )
 
+    def make_run_resource(
+        self,
+        owner_name: str,
+        project_name: str,
+        run_name: str,
+        run_uuid: str,
+        content: str,
+        default_auth=False,
+    ) -> Dict:
+        try:
+            return converter.make_and_convert(
+                owner_name=owner_name,
+                project_name=project_name,
+                run_name=run_name,
+                run_uuid=run_uuid,
+                content=content,
+                default_auth=default_auth,
+            )
+        except PolypodException as e:
+            logger.info(
+                "Run could not be cleaned. Agent failed converting run manifest: {}\n{}".format(
+                    repr(e), traceback.format_exc()
+                )
+            )
+        except Exception as e:
+            logger.info(
+                "Agent failed during compilation with unknown exception: {}\n{}".format(
+                    repr(e), traceback.format_exc()
+                )
+            )
+
     def prepare_run_resource(
         self,
         owner_name: str,
@@ -197,6 +276,7 @@ class BaseAgent:
                 run_uuid=run_uuid,
                 content=content,
                 default_auth=True,
+                agent_content=self.content,
             )
         except PolypodException as e:
             self.log_run_failed(
@@ -215,7 +295,7 @@ class BaseAgent:
                 message="Agent failed during compilation with unknown exception.\n",
             )
 
-    def create_run(self, run_data: Tuple[str, str, str, str]):
+    def submit_run(self, run_data: Tuple[str, str, str, str]):
         run_owner, run_project, run_uuid = get_run_info(run_instance=run_data[0])
         resource = self.prepare_run_resource(
             owner_name=run_owner,
@@ -224,14 +304,13 @@ class BaseAgent:
             run_uuid=run_uuid,
             content=run_data[3],
         )
+        if not resource:
+            return
 
         try:
             self.spawner.create(
                 run_uuid=run_uuid, run_kind=run_data[1], resource=resource
             )
-            self.log_run_scheduled(
-                run_owner=run_owner, run_project=run_project, run_uuid=run_uuid
-            )
         except ApiException as e:
             if e.status == 409:
                 logger.info("Run already running, triggering an apply mechanism.")
@@ -246,7 +325,41 @@ class BaseAgent:
                 )
         except Exception as e:
             self.log_run_failed(
-                run_owner=run_owner, run_project=run_project, run_uuid=run_uuid, exc=e
+                run_owner=run_owner,
+                run_project=run_project,
+                run_uuid=run_uuid,
+                exc=e,
+            )
+
+    def make_and_create_run(
+        self, run_data: Tuple[str, str, str, str], default_auth: bool = False
+    ):
+        run_owner, run_project, run_uuid = get_run_info(run_instance=run_data[0])
+        resource = self.make_run_resource(
+            owner_name=run_owner,
+            project_name=run_project,
+            run_name=run_data[2],
+            run_uuid=run_uuid,
+            content=run_data[3],
+            default_auth=default_auth,
+        )
+        if not resource:
+            return
+
+        try:
+            self.spawner.create(
+                run_uuid=run_uuid, run_kind=run_data[1], resource=resource
+            )
+        except ApiException as e:
+            if e.status == 409:
+                logger.info("Run already running, triggering an apply mechanism.")
+            else:
+                logger.info("Run submission error.")
+        except Exception as e:
+            logger.info(
+                "Run could not be cleaned. Agent failed converting run manifest: {}\n{}".format(
+                    repr(e), traceback.format_exc()
+                )
             )
 
     def apply_run(self, run_data: Tuple[str, str, str, str]):
@@ -258,6 +371,8 @@ class BaseAgent:
             run_uuid=run_uuid,
             content=run_data[3],
         )
+        if not resource:
+            return
 
         try:
             self.spawner.apply(
@@ -290,3 +405,9 @@ class BaseAgent:
                 exc=e,
                 message="Agent failed stopping run.\n",
             )
+
+    def delete_run(self, run_data: Tuple[str, str, str, str]):
+        run_owner, run_project, run_uuid = get_run_info(run_instance=run_data[0])
+        self.clean_run(run_uuid=run_uuid, run_kind=run_data[1])
+        if run_data[3]:
+            self.make_and_create_run(run_data)
