@@ -1,6 +1,6 @@
 #!/usr/bin/python
 #
-# Copyright 2018-2020 Polyaxon, Inc.
+# Copyright 2018-2021 Polyaxon, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -22,70 +22,58 @@ from polyaxon_sdk import V1Project
 from polyaxon_sdk.rest import ApiException
 from urllib3.exceptions import HTTPError
 
-from polyaxon import settings
 from polyaxon.cli.dashboard import get_dashboard_url
 from polyaxon.cli.errors import handle_cli_error
 from polyaxon.cli.init import init as init_project
+from polyaxon.cli.options import OPTIONS_OWNER, OPTIONS_PROJECT
+from polyaxon.cli.utils import get_entity_details
 from polyaxon.client import ProjectClient
-from polyaxon.constants import DEFAULT
 from polyaxon.env_vars.getters import get_project_or_local
-from polyaxon.managers.project import ProjectManager
+from polyaxon.env_vars.getters.owner_entity import resolve_entity_info
+from polyaxon.env_vars.getters.user import get_local_owner
+from polyaxon.logger import clean_outputs
+from polyaxon.managers.project import ProjectConfigManager
 from polyaxon.utils import cache
+from polyaxon.utils.cache import get_local_project
 from polyaxon.utils.formatting import (
     Printer,
     dict_tabulate,
-    dict_to_tabulate,
     get_meta_response,
     list_dicts_to_tabulate,
 )
 from polyaxon.utils.validation import validate_tags
 
 
-def get_project_details(project):
-    if project.description:
-        Printer.print_header("Project description:")
-        click.echo("{}\n".format(project.description))
-
-    response = dict_to_tabulate(
-        project.to_dict(), humanize_values=True, exclude_attrs=["description"]
-    )
-
-    Printer.print_header("Project info:")
-    dict_tabulate(response)
-
-
 @click.group()
-@click.option("--project", "-p", type=str)
+@click.option(*OPTIONS_PROJECT["args"], "_project", **OPTIONS_PROJECT["kwargs"])
 @click.pass_context
-def project(ctx, project):  # pylint:disable=redefined-outer-name
+@clean_outputs
+def project(ctx, _project):  # pylint:disable=redefined-outer-name
     """Commands for projects."""
+    if _project:
+        Printer.print_warning(
+            "Passing arguments to command groups is deprecated and will be removed in v1.2! "
+            "Please use arguments on the sub-command directly: "
+            "`polyaxon project SUB_COMMAND --help`"
+        )
     if ctx.invoked_subcommand not in ["create", "ls"]:
         ctx.obj = ctx.obj or {}
-        ctx.obj["project"] = project
+        ctx.obj["project"] = _project
 
 
 @project.command()
 @click.option(
-    "--name",
-    required=True,
-    type=str,
-    help="Name of the project, must be unique for the owner namespace.",
-)
-@click.option(
-    "--owner",
-    "-o",
-    type=str,
-    help="Name of the owner/namespace, "
-    "if not provided it will default to the namespace of the current user.",
+    "--name", type=str, help="The project name, e.g. 'mnist' or 'acme/mnist'."
 )
 @click.option("--description", type=str, help="Description of the project.")
 @click.option("--tags", type=str, help="Tags of the project, comma separated values.")
 @click.option(
-    "--private", is_flag=True, help="Set the visibility of the project to private."
+    "--public", is_flag=True, help="Set the visibility of the project to public."
 )
 @click.option("--init", is_flag=True, help="Initialize the project after creation.")
 @click.pass_context
-def create(ctx, name, owner, description, tags, private, init):
+@clean_outputs
+def create(ctx, name, description, tags, public, init):
     """Create a new project.
 
     Uses /docs/core/cli/#caching
@@ -94,27 +82,40 @@ def create(ctx, name, owner, description, tags, private, init):
 
     \b
     $ polyaxon project create --name=cats-vs-dogs --description="Image Classification with DL"
+
+    \b
+    $ polyaxon project create --name=owner/name --description="Project Description"
     """
-    owner = owner or settings.AUTH_CONFIG.username or DEFAULT
+    if not name:
+        Printer.print_error(
+            "Please provide a valid name to create a project.",
+            command_help="project create",
+            sys_exit=True,
+        )
+    owner, project_name = resolve_entity_info(
+        name or ctx.obj.get("project"), is_cli=True, entity_name="project"
+    )
+
     tags = validate_tags(tags)
 
     if not owner:
         Printer.print_error(
-            "Please login first or provide a valid owner --owner. "
-            "`polyaxon login --help`"
+            "Please provide a valid name with an owner namespace: --name=owner/project."
         )
         sys.exit(1)
 
     try:
         project_config = V1Project(
-            name=name, description=description, tags=tags, is_public=not private
+            name=project_name, description=description, tags=tags, is_public=public
         )
         polyaxon_client = ProjectClient(owner=owner)
         _project = polyaxon_client.create(project_config)
         config = polyaxon_client.client.sanitize_for_serialization(_project)
-        cache.cache(config_manager=ProjectManager, config=config)
+        cache.cache(config_manager=ProjectConfigManager, config=config)
     except (ApiException, HTTPError) as e:
-        handle_cli_error(e, message="Could not create project `{}`.".format(name))
+        handle_cli_error(
+            e, message="Could not create project `{}`.".format(project_name)
+        )
         sys.exit(1)
 
     Printer.print_success(
@@ -128,17 +129,15 @@ def create(ctx, name, owner, description, tags, private, init):
 
     if init:
         ctx.obj = {}
-        ctx.invoke(init_project, project=name)
+        ctx.invoke(
+            init_project,
+            project="{}/{}".format(owner, project_name),
+            polyaxonignore=True,
+        )
 
 
 @project.command()
-@click.option(
-    "--owner",
-    "-o",
-    type=str,
-    help="Name of the owner/namespace, "
-    "if not provided it will default to the namespace of the current user.",
-)
+@click.option(*OPTIONS_OWNER["args"], **OPTIONS_OWNER["kwargs"])
 @click.option(
     "--query", "-q", type=str, help="To filter the projects based on this query spec."
 )
@@ -147,17 +146,15 @@ def create(ctx, name, owner, description, tags, private, init):
 )
 @click.option("--limit", type=int, help="To limit the list of projects.")
 @click.option("--offset", type=int, help="To offset the list of projects.")
+@clean_outputs
 def ls(owner, query, sort, limit, offset):
     """List projects.
 
     Uses /docs/core/cli/#caching
     """
-    owner = owner or settings.AUTH_CONFIG.username or DEFAULT
+    owner = owner or get_local_owner(is_cli=True)
     if not owner:
-        Printer.print_error(
-            "Please login first or provide a valid owner --owner. "
-            "`polyaxon login --help`"
-        )
+        Printer.print_error("Please provide a valid owner: --owner/-o.")
         sys.exit(1)
 
     try:
@@ -171,11 +168,11 @@ def ls(owner, query, sort, limit, offset):
 
     meta = get_meta_response(response)
     if meta:
-        Printer.print_header("Projects for current user")
+        Printer.print_header("Projects for owner {}".format(owner))
         Printer.print_header("Navigation:")
         dict_tabulate(meta)
     else:
-        Printer.print_header("No projects found for current user")
+        Printer.print_header("No projects found for owner {}".format(owner))
 
     objects = list_dicts_to_tabulate(
         [o.to_dict() for o in response.results],
@@ -184,10 +181,8 @@ def ls(owner, query, sort, limit, offset):
             "uuid",
             "readme",
             "description",
-            "is_deleted",
             "owner",
             "user_email",
-            "teams",
             "role",
             "settings",
         ],
@@ -198,8 +193,10 @@ def ls(owner, query, sort, limit, offset):
 
 
 @project.command()
+@click.option(*OPTIONS_PROJECT["args"], "_project", **OPTIONS_PROJECT["kwargs"])
 @click.pass_context
-def get(ctx):
+@clean_outputs
+def get(ctx, _project):
     """Get info for current project, by project_name, or owner/project_name.
 
     Uses /docs/core/cli/#caching
@@ -214,9 +211,11 @@ def get(ctx):
     To get a project by name
 
     \b
-    $ polyaxon project get owner/project
+    $ polyaxon project get -p owner/project
     """
-    owner, project_name = get_project_or_local(ctx.obj.get("project"), is_cli=True)
+    owner, project_name = get_project_or_local(
+        _project or ctx.obj.get("project"), is_cli=True
+    )
 
     try:
         polyaxon_client = ProjectClient(owner=owner, project=project_name)
@@ -225,12 +224,12 @@ def get(ctx):
             polyaxon_client.project_data
         )
         cache.cache(
-            config_manager=ProjectManager,
+            config_manager=ProjectConfigManager,
             config=config,
             owner=owner,
             project=project_name,
         )
-        get_project_details(polyaxon_client.project_data)
+        get_entity_details(polyaxon_client.project_data, "Project")
     except (ApiException, HTTPError) as e:
         handle_cli_error(
             e, message="Could not get project `{}`.".format(project_name), sys_exit=True
@@ -238,13 +237,17 @@ def get(ctx):
 
 
 @project.command()
+@click.option(*OPTIONS_PROJECT["args"], "_project", **OPTIONS_PROJECT["kwargs"])
 @click.pass_context
-def delete(ctx):
+@clean_outputs
+def delete(ctx, _project):
     """Delete project.
 
     Uses /docs/core/cli/#caching
     """
-    owner, project_name = get_project_or_local(ctx.obj.get("project"), is_cli=True)
+    owner, project_name = get_project_or_local(
+        _project or ctx.obj.get("project"), is_cli=True
+    )
 
     if not click.confirm(
         "Are sure you want to delete project `{}/{}`".format(owner, project_name)
@@ -254,36 +257,40 @@ def delete(ctx):
 
     try:
         polyaxon_client = ProjectClient(owner=owner, project=project_name)
-        response = polyaxon_client.delete()
-        local_project = ProjectManager.get_config()
+        polyaxon_client.delete()
+        local_project = get_local_project()
         if local_project and (owner, project_name) == (
-            local_project.user,
+            local_project.owner,
             local_project.name,
         ):
             # Purge caching
-            ProjectManager.purge()
+            ProjectConfigManager.purge()
     except (ApiException, HTTPError) as e:
         handle_cli_error(
             e, message="Could not delete project `{}/{}`.".format(owner, project_name)
         )
         sys.exit(1)
 
-    if response.status_code == 204:
-        Printer.print_success(
-            "Project `{}/{}` was delete successfully".format(owner, project_name)
-        )
+    Printer.print_success(
+        "Project `{}/{}` was delete successfully".format(owner, project_name)
+    )
 
 
 @project.command()
+@click.option(*OPTIONS_PROJECT["args"], "_project", **OPTIONS_PROJECT["kwargs"])
 @click.option(
     "--name", type=str, help="Name of the project, must be unique for the same user."
 )
 @click.option("--description", type=str, help="Description of the project.")
+@click.option(
+    "--tags", type=str, help="Tags of the run, comma separated values (optional)."
+)
 @click.option(
     "--private", type=bool, help="Set the visibility of the project to private/public."
 )
 @click.pass_context
-def update(ctx, name, description, private):
+@clean_outputs
+def update(ctx, _project, name, description, tags, private):
     """Update project.
 
     Uses /docs/core/cli/#caching
@@ -291,15 +298,17 @@ def update(ctx, name, description, private):
     Example:
 
     \b
-    $ polyaxon update foobar --description="Image Classification with DL using TensorFlow"
+    $ polyaxon project update foobar --description="Image Classification with DL using TensorFlow"
 
     \b
-    $ polyaxon update mike1/foobar --description="Image Classification with DL using TensorFlow"
+    $ polyaxon project update mike1/foobar --description="Image Classification with DL using TensorFlow"
 
     \b
     $ polyaxon update --tags="foo, bar"
     """
-    owner, project_name = get_project_or_local(ctx.obj.get("project"), is_cli=True)
+    owner, project_name = get_project_or_local(
+        _project or ctx.obj.get("project"), is_cli=True
+    )
 
     update_dict = {}
     if name:
@@ -308,6 +317,10 @@ def update(ctx, name, description, private):
     if description:
         update_dict["description"] = description
 
+    tags = validate_tags(tags)
+    if tags:
+        update_dict["tags"] = tags
+
     if private is not None:
         update_dict["is_public"] = not private
 
@@ -325,10 +338,11 @@ def update(ctx, name, description, private):
         sys.exit(1)
 
     Printer.print_success("Project updated.")
-    get_project_details(response)
+    get_entity_details(response, "Project")
 
 
 @project.command()
+@click.option(*OPTIONS_PROJECT["args"], "_project", **OPTIONS_PROJECT["kwargs"])
 @click.option(
     "--yes",
     "-y",
@@ -344,9 +358,12 @@ def update(ctx, name, description, private):
     help="Print the url of the dashboard for this project.",
 )
 @click.pass_context
-def dashboard(ctx, yes, url):
+@clean_outputs
+def dashboard(ctx, _project, yes, url):
     """Open this operation's dashboard details in browser."""
-    owner, project_name = get_project_or_local(ctx.obj.get("project"), is_cli=True)
+    owner, project_name = get_project_or_local(
+        _project or ctx.obj.get("project"), is_cli=True
+    )
     project_url = get_dashboard_url(subpath="{}/{}".format(owner, project_name))
     if url:
         Printer.print_header("The dashboard is available at: {}".format(project_url))
