@@ -1,6 +1,6 @@
 #!/usr/bin/python
 #
-# Copyright 2018-2020 Polyaxon, Inc.
+# Copyright 2018-2021 Polyaxon, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -43,6 +43,7 @@ from polyaxon.deploy.schemas.ssl import SSLSchema
 from polyaxon.deploy.schemas.ui import UISchema
 from polyaxon.schemas.base import BaseCamelSchema, BaseConfig
 from polyaxon.schemas.types import ConnectionTypeSchema
+from polyaxon.utils.signal_decorators import check_partial
 
 
 def validate_connections(artifacts_store, connections):
@@ -140,7 +141,15 @@ def wrong_agent_deployment_keys(**kwargs):
 
 
 def validate_platform_deployment(
-    postgresql, redis, rabbitmq, broker, scheduler, worker, beat, external_services
+    postgresql,
+    redis,
+    rabbitmq,
+    broker,
+    scheduler,
+    compiler,
+    worker,
+    beat,
+    external_services,
 ):
     check_postgres(postgresql, external_services)
     redis_used, redis_is_broker = check_redis(redis, external_services, broker)
@@ -151,7 +160,7 @@ def validate_platform_deployment(
             "you don't need to deploy both!"
         )
     broker_defined = rabbitmq_used or redis_used
-    services = [scheduler, worker, beat]
+    services = [scheduler, compiler, worker, beat]
     if broker_is_required(services) and not broker_defined:
         raise ValidationError(
             "You enabled some services that require a broker, please set redis or rabbitmq!"
@@ -220,6 +229,7 @@ class DeploymentSchema(BaseCamelSchema):
     api = fields.Nested(ApiServiceSchema, allow_none=True)
     streams = fields.Nested(ApiServiceSchema, allow_none=True)
     scheduler = fields.Nested(WorkerServiceSchema, allow_none=True)
+    compiler = fields.Nested(WorkerServiceSchema, allow_none=True)
     worker = fields.Nested(WorkerServiceSchema, allow_none=True)
     beat = fields.Nested(ServiceSchema, allow_none=True)
     agent = fields.Nested(AgentServiceSchema, allow_none=True)
@@ -267,10 +277,12 @@ class DeploymentSchema(BaseCamelSchema):
         return DeploymentConfig
 
     @validates_schema
+    @check_partial
     def validate_connections(self, data, **kwargs):
         validate_connections(data.get("artifacts_store"), data.get("connections"))
 
     @validates_schema
+    @check_partial
     def validate_deployment(self, data, **kwargs):
         validate_deployment_chart(
             deployment_chart=data.get("deployment_chart"),
@@ -283,6 +295,7 @@ class DeploymentSchema(BaseCamelSchema):
             rabbitmq=data.get("rabbitmq"),
             broker=data.get("broker"),
             scheduler=data.get("scheduler"),
+            compiler=data.get("compiler"),
             worker=data.get("worker"),
             beat=data.get("beat"),
             external_services=data.get("external_services"),
@@ -349,6 +362,7 @@ class DeploymentConfig(BaseConfig):
         api=None,
         streams=None,
         scheduler=None,
+        compiler=None,
         worker=None,
         beat=None,
         agent=None,
@@ -398,6 +412,7 @@ class DeploymentConfig(BaseConfig):
             rabbitmq=rabbitmq,
             broker=broker,
             scheduler=scheduler,
+            compiler=compiler,
             worker=worker,
             beat=beat,
             external_services=external_services,
@@ -431,6 +446,7 @@ class DeploymentConfig(BaseConfig):
         self.api = api
         self.streams = streams
         self.scheduler = scheduler
+        self.compiler = compiler
         self.worker = worker
         self.beat = beat
         self.agent = agent
@@ -479,6 +495,7 @@ class DeploymentConfig(BaseConfig):
                 global_concurrency=global_concurrency,
                 api=api,
                 scheduler=scheduler,
+                compiler=compiler,
                 worker=worker,
                 beat=beat,
                 tables_hook=tables_hook,
