@@ -1,6 +1,6 @@
 #!/usr/bin/python
 #
-# Copyright 2018-2020 Polyaxon, Inc.
+# Copyright 2018-2021 Polyaxon, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -15,6 +15,7 @@
 # limitations under the License.
 import polyaxon_sdk
 
+from polyaxon.utils.date_utils import parse_datetime
 from polyaxon.utils.tz_utils import now
 
 
@@ -32,12 +33,7 @@ class V1Stages(polyaxon_sdk.V1Stages):
         DISABLED: "disabled"
     """
 
-    CHOICES = (
-        (polyaxon_sdk.V1Stages.TESTING, polyaxon_sdk.V1Stages.TESTING),
-        (polyaxon_sdk.V1Stages.STAGING, polyaxon_sdk.V1Stages.STAGING),
-        (polyaxon_sdk.V1Stages.PRODUCTION, polyaxon_sdk.V1Stages.PRODUCTION),
-        (polyaxon_sdk.V1Stages.DISABLED, polyaxon_sdk.V1Stages.DISABLED),
-    )
+    pass
 
 
 class V1Statuses(polyaxon_sdk.V1Statuses):
@@ -50,6 +46,7 @@ class V1Statuses(polyaxon_sdk.V1Statuses):
 
     Enum:
         CREATED: "created"
+        ON_SCHEDULE: "on_schedule"
         RESUMING: "resuming"
         WARNING: "warning"
         UNSCHEDULABLE: "unschedulable"
@@ -68,30 +65,14 @@ class V1Statuses(polyaxon_sdk.V1Statuses):
         UNKNOWN: "unknown"
     """
 
-    CHOICES = (
-        (polyaxon_sdk.V1Statuses.CREATED, polyaxon_sdk.V1Statuses.CREATED),
-        (polyaxon_sdk.V1Statuses.RESUMING, polyaxon_sdk.V1Statuses.RESUMING),
-        (polyaxon_sdk.V1Statuses.WARNING, polyaxon_sdk.V1Statuses.WARNING),
-        (polyaxon_sdk.V1Statuses.UNSCHEDULABLE, polyaxon_sdk.V1Statuses.UNSCHEDULABLE),
-        (polyaxon_sdk.V1Statuses.COMPILED, polyaxon_sdk.V1Statuses.COMPILED),
-        (polyaxon_sdk.V1Statuses.QUEUED, polyaxon_sdk.V1Statuses.QUEUED),
-        (polyaxon_sdk.V1Statuses.SCHEDULED, polyaxon_sdk.V1Statuses.SCHEDULED),
-        (polyaxon_sdk.V1Statuses.STARTING, polyaxon_sdk.V1Statuses.STARTING),
-        (polyaxon_sdk.V1Statuses.RUNNING, polyaxon_sdk.V1Statuses.RUNNING),
-        (polyaxon_sdk.V1Statuses.INITIALIZING, polyaxon_sdk.V1Statuses.INITIALIZING),
-        (polyaxon_sdk.V1Statuses.PROCESSING, polyaxon_sdk.V1Statuses.PROCESSING),
-        (polyaxon_sdk.V1Statuses.SUCCEEDED, polyaxon_sdk.V1Statuses.SUCCEEDED),
-        (polyaxon_sdk.V1Statuses.FAILED, polyaxon_sdk.V1Statuses.FAILED),
-        (
-            polyaxon_sdk.V1Statuses.UPSTREAM_FAILED,
-            polyaxon_sdk.V1Statuses.UPSTREAM_FAILED,
-        ),
-        (polyaxon_sdk.V1Statuses.STOPPING, polyaxon_sdk.V1Statuses.STOPPING),
-        (polyaxon_sdk.V1Statuses.STOPPED, polyaxon_sdk.V1Statuses.STOPPED),
-        (polyaxon_sdk.V1Statuses.SKIPPED, polyaxon_sdk.V1Statuses.SKIPPED),
-        (polyaxon_sdk.V1Statuses.RETRYING, polyaxon_sdk.V1Statuses.RETRYING),
-        (polyaxon_sdk.V1Statuses.UNKNOWN, polyaxon_sdk.V1Statuses.UNKNOWN),
-    )
+    allowable_hook_values = [
+        polyaxon_sdk.V1Statuses.FAILED,
+        polyaxon_sdk.V1Statuses.STOPPED,
+        polyaxon_sdk.V1Statuses.SUCCEEDED,
+        polyaxon_sdk.V1Statuses.SKIPPED,
+        polyaxon_sdk.V1Statuses.UPSTREAM_FAILED,
+        polyaxon_sdk.V1Statuses.DONE,
+    ]
 
 
 class StatusColor:
@@ -137,28 +118,28 @@ class LifeCycle:
     WARNING_VALUES = {V1Statuses.UNSCHEDULABLE, V1Statuses.WARNING}
     SAFE_STOP_VALUES = {
         V1Statuses.CREATED,
+        V1Statuses.ON_SCHEDULE,
         V1Statuses.RESUMING,
         V1Statuses.COMPILED,
     }
     PENDING_VALUES = {
         V1Statuses.CREATED,
+        V1Statuses.ON_SCHEDULE,
         V1Statuses.RESUMING,
-        V1Statuses.SCHEDULED,
     }
     COMPILABLE_VALUES = {
         V1Statuses.CREATED,
+        V1Statuses.ON_SCHEDULE,
         V1Statuses.RESUMING,
         V1Statuses.RETRYING,
     }
     RUNNING_VALUES = {
+        V1Statuses.SCHEDULED,
         V1Statuses.STARTING,
-        V1Statuses.INITIALIZING,
         V1Statuses.PROCESSING,
         V1Statuses.RUNNING,
     }
-    ON_K8S_VALUES = (
-        RUNNING_VALUES | WARNING_VALUES | {V1Statuses.SCHEDULED, V1Statuses.UNKNOWN}
-    )
+    ON_K8S_VALUES = RUNNING_VALUES | WARNING_VALUES | {V1Statuses.UNKNOWN}
     DONE_VALUES = {
         V1Statuses.FAILED,
         V1Statuses.UPSTREAM_FAILED,
@@ -273,6 +254,33 @@ class LifeCycle:
         """Checks if a run with this status is skipped."""
         return status == V1Statuses.SKIPPED
 
+    @classmethod
+    def set_started_at(cls, entity) -> bool:
+        # We allow to override started_at if the value is running
+        if entity.started_at is not None:
+            return False
+
+        if cls.is_running(entity.status):
+            entity.started_at = now()
+            # Update wait_time
+            if entity.wait_time is None:
+                entity.wait_time = (entity.started_at - entity.created_at).seconds
+            return True
+
+        return False
+
+    @classmethod
+    def set_finished_at(cls, entity) -> bool:
+        if cls.is_done(entity.status) and entity.finished_at is None:
+            entity.finished_at = now()
+            if entity.started_at is None:  # We should not have this case
+                entity.started_at = entity.created_at
+            # Update duration
+            if entity.duration is None:
+                entity.duration = (entity.finished_at - entity.started_at).seconds
+            return True
+        return False
+
 
 class ConditionMixin:
     @classmethod
@@ -300,6 +308,10 @@ class ConditionMixin:
     def __eq__(self, other):
         return self.type == other.type and self.status == other.status
 
+    @classmethod
+    def get_last_update_time(cls, value):
+        return parse_datetime(value)
+
 
 class V1StatusCondition(ConditionMixin, polyaxon_sdk.V1StatusCondition):
     pass
