@@ -1,6 +1,6 @@
 #!/usr/bin/python
 #
-# Copyright 2018-2020 Polyaxon, Inc.
+# Copyright 2018-2021 Polyaxon, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -28,6 +28,7 @@ from polyaxon.polyflow.optimization import OptimizationMetricSchema
 from polyaxon.schemas.base import BaseCamelSchema, BaseConfig
 from polyaxon.schemas.fields.ref_or_obj import RefOrObject
 from polyaxon.schemas.fields.swagger import SwaggerField
+from polyaxon.utils.signal_decorators import check_partial
 
 
 class AcquisitionFunctions:
@@ -136,6 +137,7 @@ class UtilityFunctionSchema(BaseCamelSchema):
         return UtilityFunctionConfig
 
     @validates_schema
+    @check_partial
     def validate_utility_function(self, data, **kwargs):
         validate_utility_function(
             acquisition_function=data.get("acquisition_function"),
@@ -194,19 +196,20 @@ class BayesSchema(BaseCamelSchema):
         keys=fields.Str(), values=fields.Nested(HpParamSchema), required=True
     )
     seed = RefOrObject(fields.Int(allow_none=True))
-    concurrency = fields.Int(allow_none=True)
+    concurrency = RefOrObject(fields.Int(allow_none=True))
     container = SwaggerField(
         cls=k8s_schemas.V1Container,
         defaults={"name": MAIN_JOB_CONTAINER},
         allow_none=True,
     )
-    early_stopping = fields.Nested(EarlyStoppingSchema, many=True, allow_none=True)
+    early_stopping = fields.List(fields.Nested(EarlyStoppingSchema), allow_none=True)
 
     @staticmethod
     def schema_config():
         return V1Bayes
 
     @validates_schema
+    @check_partial
     def validate_matrix(self, data, **kwargs):
         """Validates matrix data and creates the config objects"""
         validate_matrix(data.get("params"))
