@@ -1,6 +1,6 @@
 #!/usr/bin/python
 #
-# Copyright 2018-2020 Polyaxon, Inc.
+# Copyright 2018-2021 Polyaxon, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,26 +13,33 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
+import math
+
+from typing import Tuple
 
 import polyaxon_sdk
 
 from marshmallow import fields, validate
 
+from polyaxon.containers.names import MAIN_JOB_CONTAINER
+from polyaxon.k8s import k8s_schemas
 from polyaxon.polyflow.early_stopping import EarlyStoppingSchema
+from polyaxon.polyflow.matrix.base import BaseSearchConfig
 from polyaxon.polyflow.matrix.kinds import V1MatrixKind
-from polyaxon.polyflow.matrix.params import MatrixSchema
+from polyaxon.polyflow.matrix.params import HpParamSchema
 from polyaxon.polyflow.optimization import (
     OptimizationMetricSchema,
     OptimizationResourceSchema,
 )
-from polyaxon.schemas.base import BaseCamelSchema, BaseConfig
+from polyaxon.schemas.base import BaseCamelSchema
 from polyaxon.schemas.fields.ref_or_obj import RefOrObject
+from polyaxon.schemas.fields.swagger import SwaggerField
 
 
 class HyperbandSchema(BaseCamelSchema):
     kind = fields.Str(allow_none=True, validate=validate.Equal(V1MatrixKind.HYPERBAND))
     params = fields.Dict(
-        keys=fields.Str(), values=fields.Nested(MatrixSchema), allow_none=True
+        keys=fields.Str(), values=fields.Nested(HpParamSchema), allow_none=True
     )
     max_iterations = RefOrObject(fields.Int(validate=validate.Range(min=1)))
     eta = RefOrObject(fields.Float(validate=validate.Range(min=0)))
@@ -40,15 +47,20 @@ class HyperbandSchema(BaseCamelSchema):
     metric = fields.Nested(OptimizationMetricSchema)
     resume = RefOrObject(fields.Boolean(allow_none=True))
     seed = RefOrObject(fields.Int(allow_none=True))
-    concurrency = fields.Int(allow_none=True)
-    early_stopping = fields.Nested(EarlyStoppingSchema, many=True, allow_none=True)
+    concurrency = RefOrObject(fields.Int(allow_none=True))
+    container = SwaggerField(
+        cls=k8s_schemas.V1Container,
+        defaults={"name": MAIN_JOB_CONTAINER},
+        allow_none=True,
+    )
+    early_stopping = fields.List(fields.Nested(EarlyStoppingSchema), allow_none=True)
 
     @staticmethod
     def schema_config():
         return V1Hyperband
 
 
-class V1Hyperband(BaseConfig, polyaxon_sdk.V1Hyperband):
+class V1Hyperband(BaseSearchConfig, polyaxon_sdk.V1Hyperband):
     """Hyperband is a relatively new method for tuning iterative algorithms.
     It performs random sampling and attempts to gain an edge
     by using time spent optimizing in the best way.
@@ -76,7 +88,7 @@ class V1Hyperband(BaseConfig, polyaxon_sdk.V1Hyperband):
     Args:
         kind: string, should be equal to `hyperband`
         params: List[Dict[str,
-        [params](/docs/automation/optimization-engine/params/#discrete-values)]]
+            [params](/docs/automation/optimization-engine/params/#discrete-values)]]
         max_iterations: int
         eta: int
         resource: V1OptimizationResource
@@ -259,6 +271,16 @@ class V1Hyperband(BaseConfig, polyaxon_sdk.V1Hyperband):
     For more details please check the
     [early stopping section](/docs/automation/helpers/early-stopping/).
 
+    ### container
+
+    The container with the logic for creating new suggestions based on bayesian optimization,
+    users can override this section to provide different resources requirements for the tuner.
+
+    ```yaml
+    >>> matrix:
+    >>>   kind: hyperband
+    >>>   container: ...
+    ```
 
     ## Example
 
@@ -324,14 +346,110 @@ class V1Hyperband(BaseConfig, polyaxon_sdk.V1Hyperband):
 
     |              | bucket=4   |                | bucket=3   |                 | bucket=2    |                | bucket=1   |                 | bucket=0   |                | # noqa
     |--------------|------------|----------------|------------|-----------------|-------------|----------------|------------|-----------------|------------|----------------| # noqa
-    |iteration     |num configs | resource alloc |num configs | resource alloc  |num configs  |resource alloc  |num configs | resource alloc  |num configs | resource alloc | # noqa
-    |0             |81          |  1             |27          |               3 |9            | 9              |6           |  27             |5           |              81| # noqa
-    |1             |27          |  3             |9           |              9  |3            | 27             |2           |  81             |            |                | # noqa
-    |2             |9           | 9              |3           |              27 |1            | 81             |            |                 |            |                | # noqa
-    |3             |3           | 27             |1           |              81 |             |                |            |                 |            |                | # noqa
-    |4             |1           | 81             |            |                 |             |                |            |                 |            |                | # noqa
+    |iteration     |num configs |resource alloc  |num configs |resource alloc   |num configs  |resource alloc  |num configs |resource alloc   |num configs |resource alloc  | # noqa
+    |0             |81          |1               |27          |3                |9            |9               |6           |27               |5           |             81 | # noqa
+    |1             |27          |3               |9           |9                |3            |27              |2           |81               |            |                | # noqa
+    |2             |9           |9               |3           |27               |1            |81              |            |                 |            |                | # noqa
+    |3             |3           |27              |1           |81               |             |                |            |                 |            |                | # noqa
+    |4             |1           |81              |            |                 |             |                |            |                 |            |                | # noqa
     """
 
     SCHEMA = HyperbandSchema
     IDENTIFIER = V1MatrixKind.HYPERBAND
-    REDUCED_ATTRIBUTES = ["seed", "concurrency", "earlyStopping"]
+    REDUCED_ATTRIBUTES = ["seed", "concurrency", "earlyStopping", "container"]
+
+    def set_tuning_params(self):
+        # Maximum iterations per configuration: max_iterations
+        # Defines configuration downsampling/elimination rate (default = 3): eta
+        # number of times to run hyperband (brackets)
+        # i.e.  # of times to repeat the outer loops over the tradeoffs `s`
+        self.s_max = int(math.log(self.max_iterations) / math.log(self.eta))
+        self.B = (
+            self.s_max + 1
+        ) * self.max_iterations  # budget per bracket of successive halving
+
+    def get_bracket(self, iteration):
+        """This defines the bracket `s` in outerloop `for s in reversed(range(self.s_max))`."""
+        return self.s_max - iteration
+
+    def should_create_iteration(self, iteration, bracket_iteration):
+        """Return a boolean to indicate if we need to reschedule another iteration."""
+        bracket = self.get_bracket(iteration=iteration)
+        if bracket_iteration < bracket:
+            # The bracket is still processing
+            return False
+
+        # We can only reschedule if we can create a new bracket
+        return self.get_bracket(iteration=iteration + 1) >= 0
+
+    def get_num_runs_to_keep(self, num_runs, bracket_iteration):
+        """Return the number of configs to keep and resume."""
+        num_runs = num_runs * (self.eta ** -bracket_iteration)
+        return int(num_runs / self.eta)
+
+    def get_num_runs(self, bracket):
+        # n: initial number of configs
+        return int(
+            math.ceil(
+                (self.B / self.max_iterations) * (self.eta ** bracket) / (bracket + 1)
+            )
+        )
+
+    def get_num_runs_to_keep_for_iteration(self, iteration, bracket_iteration):
+        """Return the number of configs to keep for an iteration and iteration bracket.
+
+        This is just util function around `get_num_runs_to_keep`
+        """
+        bracket = self.get_bracket(iteration=iteration)
+        if bracket_iteration == bracket + 1:
+            # End of loop `for bracket_iteration in range(bracket + 1):`
+            return 0
+
+        num_runs = self.get_num_runs(bracket=bracket)
+        return self.get_num_runs_to_keep(
+            num_runs=num_runs, bracket_iteration=bracket_iteration
+        )
+
+    def should_reduce_configs(self, iteration, bracket_iteration):
+        """Return a boolean to indicate if we need to reschedule another bracket iteration."""
+        num_runs_to_keep = self.get_num_runs_to_keep_for_iteration(
+            iteration=iteration, bracket_iteration=bracket_iteration
+        )
+        return num_runs_to_keep > 0
+
+    def create_iteration(
+        self, iteration: int = None, bracket_iteration: int = 0
+    ) -> Tuple[int, int]:
+        """Create an iteration for hyperband."""
+        if iteration is None:
+            return 0, 0
+
+        should_create_iteration = self.should_create_iteration(
+            iteration=iteration,
+            bracket_iteration=bracket_iteration,
+        )
+        should_reduce_configs = self.should_reduce_configs(
+            iteration=iteration,
+            bracket_iteration=bracket_iteration,
+        )
+        if should_create_iteration:
+            iteration = iteration + 1
+            bracket_iteration = 0
+        elif should_reduce_configs:
+            bracket_iteration = bracket_iteration + 1
+        else:
+            raise ValueError(
+                "Hyperband create iteration failed, "
+                "could not reschedule or reduce configs"
+            )
+
+        return iteration, bracket_iteration
+
+    def should_reschedule(self, iteration, bracket_iteration):
+        """Return a boolean to indicate if we need to reschedule another iteration."""
+        return self.should_create_iteration(
+            iteration=iteration, bracket_iteration=bracket_iteration
+        ) or self.should_reduce_configs(
+            iteration=iteration,
+            bracket_iteration=bracket_iteration,
+        )
