@@ -1,6 +1,6 @@
 #!/usr/bin/python
 #
-# Copyright 2018-2020 Polyaxon, Inc.
+# Copyright 2018-2021 Polyaxon, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -19,23 +19,24 @@ import polyaxon_sdk
 from marshmallow import fields, validate
 
 from polyaxon.polyflow.early_stopping import EarlyStoppingSchema
+from polyaxon.polyflow.matrix.base import BaseSearchConfig
 from polyaxon.polyflow.matrix.kinds import V1MatrixKind
-from polyaxon.schemas.base import BaseCamelSchema, BaseConfig
+from polyaxon.schemas.base import BaseCamelSchema
 from polyaxon.schemas.fields.ref_or_obj import RefOrObject
 
 
 class MappingSchema(BaseCamelSchema):
     kind = fields.Str(allow_none=True, validate=validate.Equal(V1MatrixKind.MAPPING))
     values = RefOrObject(fields.List(fields.Dict(), required=True), required=True)
-    concurrency = fields.Int(allow_none=True)
-    early_stopping = fields.Nested(EarlyStoppingSchema, many=True, allow_none=True)
+    concurrency = RefOrObject(fields.Int(allow_none=True))
+    early_stopping = fields.List(fields.Nested(EarlyStoppingSchema), allow_none=True)
 
     @staticmethod
     def schema_config():
         return V1Mapping
 
 
-class V1Mapping(BaseConfig, polyaxon_sdk.V1Mapping):
+class V1Mapping(BaseSearchConfig, polyaxon_sdk.V1Mapping):
     """Mapping is a flexible way for dynamically executing a component sequentially or in parallel
     based on a list of parameter combinations.
 
@@ -126,7 +127,6 @@ class V1Mapping(BaseConfig, polyaxon_sdk.V1Mapping):
 
     For more details please check the
     [early stopping section](/docs/automation/helpers/early-stopping/).
-
     """
 
     SCHEMA = MappingSchema
