@@ -1,6 +1,6 @@
 #!/usr/bin/python
 #
-# Copyright 2018-2020 Polyaxon, Inc.
+# Copyright 2018-2021 Polyaxon, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,7 +16,7 @@
 from typing import List
 
 from polyaxon import settings
-from polyaxon.containers.containers import (
+from polyaxon.auxiliaries import (
     get_default_init_container,
     get_default_sidecar_container,
 )
@@ -41,7 +41,8 @@ class PolypodConfig:
     def resolve(
         self, compiled_operation: V1CompiledOperation, agent_config: AgentConfig = None
     ):
-        agent_config = agent_config or settings.AGENT_CONFIG
+        if not agent_config and settings.AGENT_CONFIG:
+            agent_config = settings.AGENT_CONFIG.clone()
         if not agent_config:
             raise PolyaxonCompilerError(
                 "Polypod configuration not found or agent not configured."
@@ -59,6 +60,7 @@ class PolypodConfig:
         self.polyaxon_sidecar = agent_config.sidecar or get_default_sidecar_container()
         self.polyaxon_init = agent_config.init or get_default_init_container()
         self.namespace = agent_config.namespace
+        self.polyaxon_sidecar.monitor_logs = agent_config.is_replica
 
     def _resolve_run_connections(
         self, compiled_operation: V1CompiledOperation, agent_config: AgentConfig
@@ -83,7 +85,7 @@ class PolypodConfig:
                 connections=compiled_operation.run.connections,
                 agent_config=agent_config,
             )
-        if compiled_operation.is_notifier:
+        if compiled_operation.is_notifier_run:
             self._resolve_notification_connections(
                 connections=compiled_operation.run.connections,
                 agent_config=agent_config,
