@@ -1,6 +1,6 @@
 #!/usr/bin/python
 #
-# Copyright 2018-2020 Polyaxon, Inc.
+# Copyright 2018-2021 Polyaxon, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -14,5 +14,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from polyaxon.polypod.compiler.contexts.contexts import resolve_globals_contexts
-from polyaxon.polypod.compiler.contexts.contexts import resolve_contexts
+from polyaxon.polypod.compiler.contexts.contexts import (
+    resolve_contexts,
+    resolve_globals_contexts,
+)
