@@ -1,6 +1,6 @@
 #!/usr/bin/python
 #
-# Copyright 2018-2020 Polyaxon, Inc.
+# Copyright 2018-2021 Polyaxon, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,6 +16,16 @@
 
 from polyaxon.polyflow import V1RunKind
 from polyaxon.polypod.compiler.converters.base import BaseConverter, ConverterAbstract
+from polyaxon.polypod.compiler.converters.helpers import (
+    CleanerConverter,
+    NotifierConverter,
+    PlatformCleanerConverter,
+    PlatformNotifierConverter,
+    PlatformTunerConverter,
+    PlatformWatchDogConverter,
+    TunerConverter,
+    WatchDogConverter,
+)
 from polyaxon.polypod.compiler.converters.job import JobConverter, PlatformJobConverter
 from polyaxon.polypod.compiler.converters.kubeflow import (
     MPIJobConverter,
@@ -29,7 +39,6 @@ from polyaxon.polypod.compiler.converters.kubeflow.pytroch_job import (
     PlatformPytorchJobConverter,
 )
 from polyaxon.polypod.compiler.converters.kubeflow.tf_job import PlatformTfJobConverter
-from polyaxon.polypod.compiler.converters.notifier import NotifierConverter
 from polyaxon.polypod.compiler.converters.service import (
     PlatformServiceConverter,
     ServiceConverter,
@@ -37,6 +46,9 @@ from polyaxon.polypod.compiler.converters.service import (
 
 CORE_CONVERTERS = {
     V1RunKind.NOTIFIER: NotifierConverter,
+    V1RunKind.CLEANER: CleanerConverter,
+    V1RunKind.TUNER: TunerConverter,
+    V1RunKind.WATCHDOG: WatchDogConverter,
     V1RunKind.JOB: JobConverter,
     V1RunKind.SERVICE: ServiceConverter,
     V1RunKind.MPIJOB: MPIJobConverter,
@@ -45,6 +57,10 @@ CORE_CONVERTERS = {
 }
 
 PLATFORM_CONVERTERS = {
+    V1RunKind.NOTIFIER: PlatformNotifierConverter,
+    V1RunKind.CLEANER: PlatformCleanerConverter,
+    V1RunKind.TUNER: PlatformTunerConverter,
+    V1RunKind.WATCHDOG: PlatformWatchDogConverter,
     V1RunKind.JOB: PlatformJobConverter,
     V1RunKind.SERVICE: PlatformServiceConverter,
     V1RunKind.MPIJOB: PlatformMPIJobConverter,
