@@ -1,6 +1,6 @@
 #!/usr/bin/python
 #
-# Copyright 2018-2020 Polyaxon, Inc.
+# Copyright 2018-2021 Polyaxon, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -44,6 +44,6 @@ def get_kf_replicas_template(
 
     template_spec[replica_name] = {
         "replicas": replica.num_replicas,
-        "restartPolicy": pod_spec.restart_policy,
+        "restartPolicy": pod_spec.restart_policy or "Never",
         "template": get_pod_template_spec(metadata=metadata, pod_spec=pod_spec),
     }
