@@ -1,6 +1,6 @@
 #!/usr/bin/python
 #
-# Copyright 2018-2020 Polyaxon, Inc.
+# Copyright 2018-2021 Polyaxon, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -38,8 +38,24 @@ def parse_negation_operation(operation: str) -> Tuple[bool, str]:
     return negation, _operation.strip()
 
 
+def parse_nil_operation(operation: str) -> Optional["QueryOpSpec"]:
+    """Parse the nil operator in an operation."""
+    _operation = operation.strip()
+    if not _operation:
+        raise PQLException("Operation is not valid: {}".format(operation))
+
+    # Check negation
+    negation, _operation = parse_negation_operation(_operation)
+
+    # Check nil
+    if _operation == "nil":
+        return QueryOpSpec("nil", negation, None)
+
+    return None
+
+
 def parse_comparison_operation(operation: str) -> Tuple[Optional[str], str]:
-    """Parse the comparision operator in an operation."""
+    """Parse the comparison operator in an operation."""
     _operation = operation.strip()
     if not _operation:
         raise PQLException("Operation is not valid: {}".format(operation))
@@ -75,10 +91,15 @@ def parse_datetime_operation(operation: str) -> "QueryOpSpec":
     # Check not allowed ops
     if "|" in _operation:
         raise PQLException(
-            "`|` is not allowed for datetime operations. "
+            "`|` is not allowed for datetime conditions. "
             "Operation: {}".format(operation)
         )
 
+    # Check nil operation
+    spec = parse_nil_operation(_operation)
+    if spec:
+        return spec
+
     # Check negation
     negation, _operation = parse_negation_operation(_operation)
 
@@ -125,22 +146,27 @@ def parse_scalar_operation(operation: str) -> "QueryOpSpec":
     # Check not allowed ops
     if "|" in _operation:
         raise PQLException(
-            "`|` is not allowed for scalar operations. "
+            "`|` is not allowed for scalar conditions. "
             "Operation: {}".format(operation)
         )
     if ".." in _operation:
         raise PQLException(
-            "`..` is not allowed for scalar operations. "
+            "`..` is not allowed for scalar conditions. "
             "Operation: {}".format(operation)
         )
 
+    # Check nil operation
+    spec = parse_nil_operation(_operation)
+    if spec:
+        return spec
+
     # Check negation
     negation, _operation = parse_negation_operation(_operation)
 
     # Check comparison operators
     op, _operation = parse_comparison_operation(_operation)
     if not op:
-        # Now the operation must be an equality param param
+        # Now the operation must be an equality param
         op = "="
 
     # Check that params are scalar (int, float)
@@ -152,7 +178,7 @@ def parse_scalar_operation(operation: str) -> "QueryOpSpec":
         except (ValueError, TypeError):
             raise PQLException(
                 "Scalar operation requires int or float params, "
-                "receive {}.".format(operation)
+                "received {}.".format(operation)
             )
     return QueryOpSpec(op, negation, _operation)
 
@@ -175,10 +201,15 @@ def parse_value_operation(operation: str) -> "QueryOpSpec":
     # Check range not allowed
     if ".." in _operation:
         raise PQLException(
-            "`..` is not allowed for value operations. "
+            "`..` is not allowed for value conditions. "
             "Operation: {}".format(operation)
         )
 
+    # Check nil operation
+    spec = parse_nil_operation(_operation)
+    if spec:
+        return spec
+
     # Check negation
     negation, _operation = parse_negation_operation(_operation)
 
@@ -186,7 +217,7 @@ def parse_value_operation(operation: str) -> "QueryOpSpec":
     op, _operation = parse_comparison_operation(_operation)
     if op:
         raise PQLException(
-            "`{}` is not allowed for value operations, "
+            "`{}` is not allowed for value conditions, "
             "Operation: {}".format(op, operation)
         )
 
@@ -197,7 +228,7 @@ def parse_value_operation(operation: str) -> "QueryOpSpec":
         params = [param.strip() for param in params if param.strip()]
         if len(params) <= 1:
             raise PQLException(
-                "`{}` is not allowed for value operations, "
+                "`{}` is not allowed for value conditions, "
                 "Operation: {}".format(op, operation)
             )
         return QueryOpSpec(op, negation, params)
@@ -232,10 +263,15 @@ def parse_search_operation(operation: str) -> "QueryOpSpec":
     # Check range not allowed
     if ".." in _operation:
         raise PQLException(
-            "`..` is not allowed for value operations. "
+            "`..` is not allowed for search conditions. "
             "Operation: {}".format(operation)
         )
 
+    # Check nil operation
+    spec = parse_nil_operation(_operation)
+    if spec:
+        return spec
+
     # Check negation
     negation, _operation = parse_negation_operation(_operation)
 
@@ -243,7 +279,7 @@ def parse_search_operation(operation: str) -> "QueryOpSpec":
     op, _operation = parse_comparison_operation(_operation)
     if op:
         raise PQLException(
-            "`{}` is not allowed for value operations, "
+            "`{}` is not allowed for search conditions, "
             "Operation: {}".format(op, operation)
         )
 
@@ -254,7 +290,7 @@ def parse_search_operation(operation: str) -> "QueryOpSpec":
         params = [param.strip() for param in params if param.strip()]
         if len(params) <= 1:
             raise PQLException(
-                "`{}` is not allowed for value operations, "
+                "`{}` is not allowed for search conditions, "
                 "Operation: {}".format(op, operation)
             )
         return QueryOpSpec(op, negation, params)
@@ -268,7 +304,7 @@ def parse_search_operation(operation: str) -> "QueryOpSpec":
         params = [param.strip() for param in params if param.strip()]
         if len(params) != 1:
             raise PQLException(
-                "`{}` is not allowed for value operations, "
+                "`{}` is not allowed for search conditions, "
                 "Operation: {}".format(op, operation)
             )
         return QueryOpSpec(op, negation, params[0])
@@ -279,7 +315,7 @@ def parse_search_operation(operation: str) -> "QueryOpSpec":
         params = [param.strip() for param in params if param.strip()]
         if len(params) != 1:
             raise PQLException(
-                "`{}` is not allowed for value operations, "
+                "`{}` is not allowed for search conditions, "
                 "Operation: {}".format(op, operation)
             )
         return QueryOpSpec(op, negation, params[0])
@@ -290,7 +326,7 @@ def parse_search_operation(operation: str) -> "QueryOpSpec":
         params = [param.strip() for param in params if param.strip()]
         if len(params) != 1:
             raise PQLException(
-                "`{}` is not allowed for value operations, "
+                "`{}` is not allowed for search conditions, "
                 "Operation: {}".format(op, operation)
             )
         return QueryOpSpec(op, negation, params[0])
@@ -315,9 +351,9 @@ def parse_expression(expression: str) -> Tuple[str, str]:
     """
     try:
         _expression = expression.strip()
-        name, operation = _expression.split(":")
-        name = name.strip()
-        operation = operation.strip()
+        parts = _expression.split(":")
+        name = parts[0].strip()
+        operation = ":".join(parts[1:]).strip()
         if not name or not operation:
             raise ValueError
     except (ValueError, AttributeError):
@@ -372,7 +408,7 @@ def parse_field(field: str) -> Tuple[str, Optional[str]]:
 
     Example:
         foo => foo, None
-        metric.foo => metric, foo
+        metrics.foo => metric, foo
     """
     _field = field.split(".")
     _field = [f.strip() for f in _field]
