@@ -1,6 +1,6 @@
 #!/usr/bin/python
 #
-# Copyright 2018-2020 Polyaxon, Inc.
+# Copyright 2018-2021 Polyaxon, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -17,22 +17,17 @@
 import os
 
 from datetime import datetime
-from typing import Optional
+from typing import List, Optional
 
 from polyaxon import settings
 from polyaxon.connections.getter import get_connection_from_type
 from polyaxon.connections.reader import get_connection_type
-from polyaxon.env_vars.keys import POLYAXON_KEYS_ARTIFACTS_STORE_NAME
+from polyaxon.env_vars.getters import get_artifacts_store_name
 from polyaxon.exceptions import PolyaxonStoresException
 from polyaxon.schemas.types import V1ConnectionType
 from polyaxon.utils.path_utils import create_tarfile, get_files_in_path, get_path
 
 
-def get_artifacts_store_name():
-    """Get the artifacts store name"""
-    return os.getenv(POLYAXON_KEYS_ARTIFACTS_STORE_NAME)
-
-
 def get_artifacts_connection() -> Optional[V1ConnectionType]:
     store_name = get_artifacts_store_name()
     if store_name:
@@ -77,6 +72,7 @@ def upload_file_or_dir(
     workers: int = 0,
     last_time: datetime = None,
     connection_type: V1ConnectionType = None,
+    exclude: List[str] = None,
 ):
     connection_type = connection_type or get_artifacts_connection()
 
@@ -87,7 +83,12 @@ def upload_file_or_dir(
         store_manager.upload_file(path_from, path_to, use_basename=False)
     else:
         store_manager.upload_dir(
-            path_from, path_to, use_basename=False, workers=workers, last_time=last_time
+            path_from,
+            path_to,
+            use_basename=False,
+            workers=workers,
+            last_time=last_time,
+            exclude=exclude,
         )
 
 
@@ -117,17 +118,21 @@ def download_file_or_dir(
     return path_to
 
 
-def delete_path(
-    subpath: str, workers: int = 0, connection_type: V1ConnectionType = None
+def delete_file_or_dir(
+    subpath: str,
+    is_file: bool = False,
+    workers: int = 0,
+    connection_type: V1ConnectionType = None,
 ):
     connection_type = connection_type or get_artifacts_connection()
 
     validate_store(connection_type)
 
-    store_path = get_path(connection_type.store_path, subpath)
-
     store_manager = get_connection_from_type(connection_type=connection_type)
-    store_manager.delete(store_path, workers=workers)
+    if is_file:
+        store_manager.delete_file(subpath)
+    else:
+        store_manager.delete(subpath, workers=workers)
 
 
 def tar_dir(download_path: str) -> str:
