@@ -1,6 +1,6 @@
 #!/usr/bin/python
 #
-# Copyright 2018-2020 Polyaxon, Inc.
+# Copyright 2018-2021 Polyaxon, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -15,16 +15,19 @@
 # limitations under the License.
 import os
 
-from dateutil import parser as dt_parser
+from typing import Any, Dict
+
+import ujson
+
 from starlette import status
 from starlette.background import BackgroundTask
 from starlette.datastructures import QueryParams
 from starlette.exceptions import HTTPException
-from starlette.responses import FileResponse, Response, UJSONResponse
+from starlette.requests import Request
+from starlette.responses import FileResponse, JSONResponse, Response
 
 from polyaxon import settings
 from polyaxon.k8s.async_manager import AsyncK8SManager
-from polyaxon.k8s.custom_resources.operation import get_resource_name, get_run_instance
 from polyaxon.k8s.logging.async_monitor import query_k8s_operation_logs
 from polyaxon.lifecycle import V1StatusCondition
 from polyaxon.polyboard.artifacts import V1ArtifactKind
@@ -48,21 +51,29 @@ from polyaxon.streams.controllers.logs import (
     get_operation_logs,
     get_tmp_operation_logs,
 )
+from polyaxon.streams.controllers.uploads import handle_upload
 from polyaxon.streams.tasks.logs import clean_tmp_logs, upload_logs
 from polyaxon.streams.tasks.notification import notify_run
 from polyaxon.utils.bool_utils import to_bool
+from polyaxon.utils.date_utils import parse_datetime
+from polyaxon.utils.fqn_utils import get_resource_name, get_resource_name_for_kind
 
 
-async def health(request):
+class UJSONResponse(JSONResponse):
+    def render(self, content: Any) -> bytes:
+        return ujson.dumps(content, ensure_ascii=False).encode("utf-8")
+
+
+async def health(request: Request) -> Response:
     return Response(status_code=status.HTTP_200_OK)
 
 
-async def get_logs(request):
+async def get_logs(request: Request) -> UJSONResponse:
     run_uuid = request.path_params["run_uuid"]
     force = to_bool(request.query_params.get("force"), handle_none=True)
     last_time = QueryParams(request.url.query).get("last_time")
     if last_time:
-        last_time = dt_parser.parse(last_time).astimezone()
+        last_time = parse_datetime(last_time).astimezone()
     last_file = QueryParams(request.url.query).get("last_file")
     files = []
 
@@ -101,9 +112,10 @@ async def get_logs(request):
     return UJSONResponse(response.to_dict())
 
 
-async def collect_logs(request):
+async def collect_logs(request: Request) -> Response:
     run_uuid = request.path_params["run_uuid"]
-    resource_name = get_resource_name(run_uuid=run_uuid)
+    run_kind = request.path_params["run_kind"]
+    resource_name = get_resource_name_for_kind(run_uuid=run_uuid, run_kind=run_kind)
     k8s_manager = AsyncK8SManager(
         namespace=settings.CLIENT_CONFIG.namespace,
         in_cluster=settings.CLIENT_CONFIG.in_cluster,
@@ -115,7 +127,7 @@ async def collect_logs(request):
     if not k8s_operation:
         raise HTTPException(
             detail="Run's logs was not collected, resource was not found.",
-            status_code=status.HTTP_400_BAD_REQUEST,
+            status_code=status.HTTP_404_NOT_FOUND,
         )
     operation_logs, _ = await query_k8s_operation_logs(
         instance=run_uuid, k8s_manager=k8s_manager, last_time=None
@@ -123,14 +135,23 @@ async def collect_logs(request):
     if k8s_manager:
         await k8s_manager.close()
     if not operation_logs:
-        return Response()
+        return Response(status_code=status.HTTP_404_NOT_FOUND)
 
-    await upload_logs(run_uuid=run_uuid, logs=operation_logs)
-    task = BackgroundTask(clean_tmp_logs, run_uuid=run_uuid)
-    return Response(background=task)
+    try:
+        await upload_logs(run_uuid=run_uuid, logs=operation_logs)
+    except Exception as e:
+        raise HTTPException(
+            detail="Run's logs was not collected, an error was raised while uploading the data %s."
+            % e,
+            status_code=status.HTTP_400_BAD_REQUEST,
+        )
+    if settings.AGENT_CONFIG.is_replica:
+        task = BackgroundTask(clean_tmp_logs, run_uuid=run_uuid)
+        return Response(background=task)
+    return Response(status_code=status.HTTP_200_OK)
 
 
-async def get_multi_runs_events(request):
+async def get_multi_runs_events(request: Request) -> UJSONResponse:
     event_kind = request.path_params["event_kind"]
     force = to_bool(request.query_params.get("force"), handle_none=True)
     if event_kind not in V1ArtifactKind.allowable_values:
@@ -154,7 +175,7 @@ async def get_multi_runs_events(request):
     return UJSONResponse({"data": events})
 
 
-async def get_run_events(request):
+async def get_run_events(request: Request) -> UJSONResponse:
     run_uuid = request.path_params["run_uuid"]
     event_kind = request.path_params["event_kind"]
     force = to_bool(request.query_params.get("force"), handle_none=True)
@@ -177,7 +198,7 @@ async def get_run_events(request):
     return UJSONResponse({"data": events})
 
 
-async def get_run_resources(request):
+async def get_run_resources(request: Request) -> UJSONResponse:
     run_uuid = request.path_params["run_uuid"]
     event_names = request.query_params.get("names")
     orient = request.query_params.get("orient")
@@ -194,14 +215,14 @@ async def get_run_resources(request):
     return UJSONResponse({"data": events})
 
 
-def inject_auth_header(request, headers):
+def inject_auth_header(request: Request, headers: Dict) -> Dict:
     auth = request.headers.get("Authorization")
     if auth:
         headers["Authorization"] = auth
     return headers
 
 
-def redirect(archived_path):
+def redirect(archived_path: str) -> Response:
     if not archived_path:
         return Response(
             content="Artifact not found: filepath={}".format(archived_path),
@@ -217,7 +238,7 @@ def redirect(archived_path):
     return Response(headers=headers)
 
 
-async def notify(request):
+async def notify(request: Request) -> Response:
     namespace = request.path_params["namespace"]
     owner = request.path_params["owner"]
     project = request.path_params["project"]
@@ -257,14 +278,16 @@ async def notify(request):
     return Response(background=task)
 
 
-async def handle_artifact(request):
+async def handle_artifact(request: Request) -> Response:
     if request.method == "GET":
         return await download_artifact(request)
     if request.method == "DELETE":
         return await delete_artifact(request)
+    if request.method == "POST":
+        return await upload_artifact(request)
 
 
-async def download_artifact(request):
+async def download_artifact(request: Request) -> Response:
     run_uuid = request.path_params["run_uuid"]
     filepath = request.query_params.get("path", "")
     stream = to_bool(request.query_params.get("stream"), handle_none=True)
@@ -286,7 +309,11 @@ async def download_artifact(request):
     return redirect(archived_path)
 
 
-async def delete_artifact(request):
+async def upload_artifact(request: Request) -> Response:
+    return await handle_upload(request=request, is_file=True)
+
+
+async def delete_artifact(request: Request) -> Response:
     run_uuid = request.path_params["run_uuid"]
     filepath = request.query_params.get("path", "")
     if not filepath:
@@ -301,17 +328,21 @@ async def delete_artifact(request):
             content="Artifact could not be deleted: filepath={}".format(subpath),
             status_code=status.HTTP_400_BAD_REQUEST,
         )
-    return Response(status_code=status.HTTP_204_NO_CONTENT,)
+    return Response(
+        status_code=status.HTTP_204_NO_CONTENT,
+    )
 
 
-async def handle_artifacts(request):
+async def handle_artifacts(request: Request) -> Response:
     if request.method == "GET":
         return await download_artifacts(request)
     if request.method == "DELETE":
         return await delete_artifacts(request)
+    if request.method == "POST":
+        return await upload_artifacts(request)
 
 
-async def download_artifacts(request):
+async def download_artifacts(request: Request) -> Response:
     run_uuid = request.path_params["run_uuid"]
     path = request.query_params.get("path", "")
     subpath = "{}/{}".format(run_uuid, path).rstrip("/")
@@ -324,7 +355,11 @@ async def download_artifacts(request):
     return redirect(archived_path)
 
 
-async def delete_artifacts(request):
+async def upload_artifacts(request: Request) -> Response:
+    return await handle_upload(request=request, is_file=False)
+
+
+async def delete_artifacts(request: Request) -> Response:
     run_uuid = request.path_params["run_uuid"]
     path = request.query_params.get("path", "")
     subpath = "{}/{}".format(run_uuid, path).rstrip("/")
@@ -334,31 +369,33 @@ async def delete_artifacts(request):
             content="Artifacts could not be deleted: filepath={}".format(subpath),
             status_code=status.HTTP_400_BAD_REQUEST,
         )
-    return Response(status_code=status.HTTP_204_NO_CONTENT,)
+    return Response(
+        status_code=status.HTTP_204_NO_CONTENT,
+    )
 
 
-async def tree_artifacts(request):
+async def tree_artifacts(request: Request) -> UJSONResponse:
     run_uuid = request.path_params["run_uuid"]
     filepath = request.query_params.get("path", "")
     ls = await list_files(subpath=run_uuid, filepath=filepath)
     return UJSONResponse(ls)
 
 
-async def error(request):
+async def error(request: Request):
     """
     An example error. Switch the `debug` setting to see either tracebacks or 500 pages.
     """
     raise RuntimeError("Oh no")
 
 
-async def not_found(request, exc):
+async def not_found(request: Request, exc) -> Response:
     """
     Return an HTTP 404 page.
     """
     return Response(status_code=status.HTTP_404_NOT_FOUND)
 
 
-async def server_error(request, exc):
+async def server_error(request: Request, exc):
     """
     Return an HTTP 500 page.
     """
