@@ -1,6 +1,6 @@
 #!/usr/bin/python
 #
-# Copyright 2018-2020 Polyaxon, Inc.
+# Copyright 2018-2021 Polyaxon, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -17,13 +17,13 @@
 import pytest
 
 from marshmallow import ValidationError
-from tests.utils import BaseTestCase
 
 from polyaxon import types
 from polyaxon.polyflow import V1RunKind
 from polyaxon.polyflow.operations import V1CompiledOperation
 from polyaxon.polyflow.params import ops_params
 from polyaxon.utils.tz_utils import now
+from tests.utils import BaseTestCase
 
 
 @pytest.mark.ops_mark
@@ -321,38 +321,32 @@ class TestCompiledOperationsConfigs(BaseTestCase):
             outputs=config.outputs,
             is_template=False,
         )
-        # Passing wrong type
-        with self.assertRaises(ValidationError):
-            ops_params.validate_params(
-                params={"param2": {"value": 1}},
-                inputs=config.inputs,
-                outputs=config.outputs,
-                is_template=False,
-            )
+        # Auto conversion
+        ops_params.validate_params(
+            params={"param2": {"value": 1}},
+            inputs=config.inputs,
+            outputs=config.outputs,
+            is_template=False,
+        )
+        ops_params.validate_params(
+            params={"param2": {"value": False}},
+            inputs=config.inputs,
+            outputs=config.outputs,
+            is_template=False,
+        )
+        ops_params.validate_params(
+            params={"param2": {"value": {"foo": "bar"}}},
+            inputs=config.inputs,
+            outputs=config.outputs,
+            is_template=False,
+        )
 
-        with self.assertRaises(ValidationError):
-            ops_params.validate_params(
-                params={"param2": {"value": False}},
-                inputs=config.inputs,
-                outputs=config.outputs,
-                is_template=False,
-            )
-
-        with self.assertRaises(ValidationError):
-            ops_params.validate_params(
-                params={"param2": {"value": {"foo": "bar"}}},
-                inputs=config.inputs,
-                outputs=config.outputs,
-                is_template=False,
-            )
-
-        with self.assertRaises(ValidationError):
-            ops_params.validate_params(
-                params={"param2": {"value": ["gs://bucket/path/to/blob/"]}},
-                inputs=config.inputs,
-                outputs=config.outputs,
-                is_template=False,
-            )
+        ops_params.validate_params(
+            params={"param2": {"value": ["gs://bucket/path/to/blob/"]}},
+            inputs=config.inputs,
+            outputs=config.outputs,
+            is_template=False,
+        )
 
         config_dict = {
             "inputs": [{"name": "param7", "type": types.WASB}],
@@ -440,13 +434,20 @@ class TestCompiledOperationsConfigs(BaseTestCase):
             )
 
         config_dict = {
-            "outputs": [{"name": "param2", "type": types.STR}],
+            "outputs": [{"name": "param2", "type": types.FLOAT}],
             "run": {"kind": V1RunKind.JOB, "container": {"image": "test"}},
         }
         config = V1CompiledOperation.from_dict(config_dict)
         # Passing correct param
         ops_params.validate_params(
-            params={"param2": {"value": "text"}},
+            params={"param2": {"value": "1.1"}},
+            inputs=config.inputs,
+            outputs=config.outputs,
+            is_template=False,
+        )
+        # Aut conversion
+        ops_params.validate_params(
+            params={"param2": {"value": False}},
             inputs=config.inputs,
             outputs=config.outputs,
             is_template=False,
@@ -454,15 +455,7 @@ class TestCompiledOperationsConfigs(BaseTestCase):
         # Passing wrong type
         with self.assertRaises(ValidationError):
             ops_params.validate_params(
-                params={"param2": {"value": 1}},
-                inputs=config.inputs,
-                outputs=config.outputs,
-                is_template=False,
-            )
-
-        with self.assertRaises(ValidationError):
-            ops_params.validate_params(
-                params={"param2": {"value": False}},
+                params={"param2": {"value": "test"}},
                 inputs=config.inputs,
                 outputs=config.outputs,
                 is_template=False,
@@ -593,9 +586,9 @@ class TestCompiledOperationsConfigs(BaseTestCase):
             V1CompiledOperation.from_dict(config_dict)
 
         config_dict = {
-            "schedule": {"kind": "exact_time", "startAt": now().isoformat()},
+            "schedule": {"kind": "datetime", "startAt": now().isoformat()},
             "termination": {"timeout": 2},
-            "run": {"kind": V1RunKind.JOB, "container": {"image": "test"},},
+            "run": {"kind": V1RunKind.JOB, "container": {"image": "test"}},
         }
         V1CompiledOperation.from_dict(config_dict)
 
@@ -634,9 +627,9 @@ class TestCompiledOperationsConfigs(BaseTestCase):
                 "kind": "mapping",
                 "values": [{"a": 1}, {"a": 1}],
             },
-            "schedule": {"kind": "exact_time", "startAt": now().isoformat()},
+            "schedule": {"kind": "datetime", "startAt": now().isoformat()},
             "termination": {"timeout": 1000},
-            "run": {"kind": V1RunKind.JOB, "container": {"image": "test"},},
+            "run": {"kind": V1RunKind.JOB, "container": {"image": "test"}},
         }
         config = V1CompiledOperation.from_dict(config_dict)
         config_to_light = config.to_light_dict()
