@@ -1,6 +1,6 @@
 #!/usr/bin/python
 #
-# Copyright 2018-2020 Polyaxon, Inc.
+# Copyright 2018-2021 Polyaxon, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -23,6 +23,7 @@ from polyaxon.connections.schemas import (
     V1K8sResourceSchema,
 )
 from polyaxon.k8s import k8s_schemas
+from polyaxon.polyboard.artifacts import V1ArtifactKind
 from polyaxon.polyflow import V1Init, V1Plugins
 from polyaxon.polypod.common.mounts import get_mounts
 from polyaxon.polypod.compiler.converters import PlatformJobConverter
@@ -38,6 +39,7 @@ from polyaxon.schemas.types import (
     V1ArtifactsType,
     V1ConnectionType,
     V1DockerfileType,
+    V1FileType,
     V1K8sResourceType,
 )
 from polyaxon.services.headers import PolyaxonServices
@@ -65,6 +67,15 @@ class TestJobConverter(BaseTestCase):
             run_uuid="run_uuid",
         )
 
+    def assert_containers(self, results, expected):
+        for c in results:
+            if "default" not in c.name and "auth" not in c.name:
+                c.name = "-".join(c.name.split("-")[:-1])
+        for c in expected:
+            if "default" not in c.name and "auth" not in c.name:
+                c.name = "-".join(c.name.split("-")[:-1])
+        assert results == expected
+
     def test_get_main_env_vars(self):
         env_vars = self.converter.get_main_env_vars()
         assert env_vars == self.converter.get_service_env_vars(
@@ -100,7 +111,7 @@ class TestJobConverter(BaseTestCase):
         )
         assert containers == []
 
-    def test_get_init_containers_with_claim_outputs(self):
+    def test_get_init_containers_with_claim_outputs(self):  # TODO
         store = V1ConnectionType(
             name="test_claim",
             kind=V1ConnectionKind.VOLUME_CLAIM,
@@ -131,14 +142,17 @@ class TestJobConverter(BaseTestCase):
             init_containers=[],
             polyaxon_init=V1PolyaxonInitContainer(image="foo/foo"),
         )
-        assert containers == [
-            get_artifacts_path_container(
-                polyaxon_init=V1PolyaxonInitContainer(image="foo/foo"),
-                artifacts_store=store,
-                run_path=self.converter.run_path,
-                auto_resume=True,
-            ),
-        ]
+        self.assert_containers(
+            containers,
+            [
+                get_artifacts_path_container(
+                    polyaxon_init=V1PolyaxonInitContainer(image="foo/foo"),
+                    artifacts_store=store,
+                    run_path=self.converter.run_path,
+                    auto_resume=True,
+                ),
+            ],
+        )
 
         # Use store for init
         containers = self.converter.get_init_containers(
@@ -149,14 +163,17 @@ class TestJobConverter(BaseTestCase):
             init_containers=[],
             polyaxon_init=V1PolyaxonInitContainer(image="foo/foo"),
         )
-        assert containers == [
-            get_store_container(
-                polyaxon_init=V1PolyaxonInitContainer(image="foo/foo"),
-                connection=store,
-                artifacts=None,
-                env=self.converter.get_init_service_env_vars(),
-            )
-        ]
+        self.assert_containers(
+            containers,
+            [
+                get_store_container(
+                    polyaxon_init=V1PolyaxonInitContainer(image="foo/foo"),
+                    connection=store,
+                    artifacts=None,
+                    env=self.converter.get_init_service_env_vars(),
+                )
+            ],
+        )
 
         # Use store for init and outputs
         containers = self.converter.get_init_containers(
@@ -169,25 +186,28 @@ class TestJobConverter(BaseTestCase):
             init_containers=[],
             polyaxon_init=V1PolyaxonInitContainer(image="foo/foo"),
         )
-        assert containers == [
-            get_artifacts_path_container(
-                polyaxon_init=V1PolyaxonInitContainer(image="foo/foo"),
-                artifacts_store=store,
-                run_path=self.converter.run_path,
-                auto_resume=True,
-            ),
-            get_store_container(
-                polyaxon_init=V1PolyaxonInitContainer(image="foo/foo"),
-                connection=store,
-                artifacts=None,
-                env=self.converter.get_init_service_env_vars(),
-                is_default_artifacts_store=True,
-            ),
-        ]
+        self.assert_containers(
+            containers,
+            [
+                get_artifacts_path_container(
+                    polyaxon_init=V1PolyaxonInitContainer(image="foo/foo"),
+                    artifacts_store=store,
+                    run_path=self.converter.run_path,
+                    auto_resume=True,
+                ),
+                get_store_container(
+                    polyaxon_init=V1PolyaxonInitContainer(image="foo/foo"),
+                    connection=store,
+                    artifacts=None,
+                    env=self.converter.get_init_service_env_vars(),
+                    is_default_artifacts_store=True,
+                ),
+            ],
+        )
 
         # Add Store
         store1 = V1ConnectionType(
-            name="test_gcs",
+            name="test_s3",
             kind=V1ConnectionKind.S3,
             schema=V1BucketConnection(bucket="s3://foo"),
             secret=None,
@@ -201,42 +221,53 @@ class TestJobConverter(BaseTestCase):
             init_connections=[
                 V1Init(
                     connection=store.name,
-                    artifacts=V1ArtifactsType(files=["/foo", "/bar"]),
+                    artifacts=V1ArtifactsType(
+                        files=["/foo", "/bar", ["from-foo", "to-foo"]]
+                    ),
                 ),
                 V1Init(
                     connection=store1.name,
-                    artifacts=V1ArtifactsType(files=["/foo", "/bar"]),
+                    artifacts=V1ArtifactsType(
+                        files=["/foo", "/bar", ["from-foo", "to-foo"]]
+                    ),
                 ),
             ],
             connection_by_names={store.name: store, store1.name: store1},
             init_containers=[],
             polyaxon_init=V1PolyaxonInitContainer(image="foo/foo"),
         )
-        assert containers == [
-            get_auth_context_container(
-                polyaxon_init=V1PolyaxonInitContainer(image="foo/foo"),
-                env=self.converter.get_auth_service_env_vars(),
-            ),
-            get_artifacts_path_container(
-                polyaxon_init=V1PolyaxonInitContainer(image="foo/foo"),
-                artifacts_store=store,
-                run_path=self.converter.run_path,
-                auto_resume=True,
-            ),
-            get_store_container(
-                polyaxon_init=V1PolyaxonInitContainer(image="foo/foo"),
-                connection=store,
-                artifacts=V1ArtifactsType(files=["/foo", "/bar"]),
-                env=self.converter.get_init_service_env_vars(),
-                is_default_artifacts_store=True,
-            ),
-            get_store_container(
-                polyaxon_init=V1PolyaxonInitContainer(image="foo/foo"),
-                connection=store1,
-                artifacts=V1ArtifactsType(files=["/foo", "/bar"]),
-                env=self.converter.get_init_service_env_vars(),
-            ),
-        ]
+        self.assert_containers(
+            containers,
+            [
+                get_auth_context_container(
+                    polyaxon_init=V1PolyaxonInitContainer(image="foo/foo"),
+                    env=self.converter.get_auth_service_env_vars(),
+                ),
+                get_artifacts_path_container(
+                    polyaxon_init=V1PolyaxonInitContainer(image="foo/foo"),
+                    artifacts_store=store,
+                    run_path=self.converter.run_path,
+                    auto_resume=True,
+                ),
+                get_store_container(
+                    polyaxon_init=V1PolyaxonInitContainer(image="foo/foo"),
+                    connection=store,
+                    artifacts=V1ArtifactsType(
+                        files=["/foo", "/bar", ["from-foo", "to-foo"]]
+                    ),
+                    env=self.converter.get_init_service_env_vars(),
+                    is_default_artifacts_store=True,
+                ),
+                get_store_container(
+                    polyaxon_init=V1PolyaxonInitContainer(image="foo/foo"),
+                    connection=store1,
+                    artifacts=V1ArtifactsType(
+                        files=["/foo", "/bar", ["from-foo", "to-foo"]]
+                    ),
+                    env=self.converter.get_init_service_env_vars(),
+                ),
+            ],
+        )
 
     def test_get_init_containers_with_dockerfiles(self):
         dockerfile_args1 = V1DockerfileType(
@@ -261,8 +292,6 @@ class TestJobConverter(BaseTestCase):
             connection_by_names={},
             polyaxon_init=V1PolyaxonInitContainer(image="foo/foo"),
         )
-        for container in containers:
-            container.name = ""
         expected_containers = [
             get_dockerfile_init_container(
                 dockerfile_args=dockerfile_args1,
@@ -282,10 +311,48 @@ class TestJobConverter(BaseTestCase):
                 run_instance=self.converter.run_instance,
             ),
         ]
-        for container in expected_containers:
-            container.name = ""
 
-        assert expected_containers == containers
+        self.assert_containers(expected_containers, containers)
+
+    def test_get_init_containers_with_files(self):
+        file_args1 = V1FileType(filename="test.sh", content="test", chmod="+x")
+        file_args2 = V1FileType(
+            filename="test.csv",
+            content="csv",
+            kind=V1ArtifactKind.CSV,
+        )
+        containers = self.converter.get_init_containers(
+            contexts=None,
+            artifacts_store=None,
+            init_connections=[
+                V1Init(dockerfile=file_args1),
+                V1Init(dockerfile=file_args2, path="/test"),
+            ],
+            init_containers=[],
+            connection_by_names={},
+            polyaxon_init=V1PolyaxonInitContainer(image="foo/foo"),
+        )
+        expected_containers = [
+            get_dockerfile_init_container(
+                dockerfile_args=file_args1,
+                polyaxon_init=V1PolyaxonInitContainer(image="foo/foo"),
+                env=self.converter.get_init_service_env_vars(),
+                contexts=None,
+                run_path=self.converter.run_path,
+                run_instance=self.converter.run_instance,
+            ),
+            get_dockerfile_init_container(
+                dockerfile_args=file_args2,
+                polyaxon_init=V1PolyaxonInitContainer(image="foo/foo"),
+                env=self.converter.get_init_service_env_vars(),
+                mount_path="/test",
+                contexts=None,
+                run_path=self.converter.run_path,
+                run_instance=self.converter.run_instance,
+            ),
+        ]
+
+        self.assert_containers(expected_containers, containers)
 
     def test_get_init_containers_with_git_without_connection(self):
         git1 = V1GitConnection(revision="test", url="https://test.com")
@@ -305,7 +372,7 @@ class TestJobConverter(BaseTestCase):
             connection_by_names={},
             polyaxon_init=V1PolyaxonInitContainer(image="foo/foo"),
         )
-        assert containers == [
+        expected_containers = [
             get_git_init_container(
                 connection=V1ConnectionType(
                     name=git1.get_name(), kind=V1ConnectionKind.GIT, schema=git1
@@ -325,6 +392,7 @@ class TestJobConverter(BaseTestCase):
                 contexts=None,
             ),
         ]
+        self.assert_containers(expected_containers, containers)
 
     def test_get_init_containers_with_store_outputs(self):
         store = V1ConnectionType(
