@@ -1,6 +1,6 @@
 #!/usr/bin/python
 #
-# Copyright 2018-2020 Polyaxon, Inc.
+# Copyright 2018-2021 Polyaxon, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,12 +16,11 @@
 
 import pytest
 
-from tests.utils import BaseTestCase
-
-from polyaxon.containers.containers import V1PolyaxonInitContainer, get_init_resources
+from polyaxon.auxiliaries import V1PolyaxonInitContainer, get_init_resources
 from polyaxon.containers.names import INIT_AUTH_CONTAINER
 from polyaxon.polypod.common.mounts import get_auth_context_mount
 from polyaxon.polypod.init.auth import get_auth_context_container
+from tests.utils import BaseTestCase
 
 
 @pytest.mark.polypod_mark
