@@ -1,6 +1,6 @@
 #!/usr/bin/python
 #
-# Copyright 2018-2020 Polyaxon, Inc.
+# Copyright 2018-2021 Polyaxon, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -14,13 +14,13 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import hyperopt
 import pytest
 
-from tests.utils import BaseTestCase
+import hyperopt
 
-from polyaxon.polyflow.parallel.hyperopt import V1Hyperopt
+from polyaxon.polyflow.matrix.hyperopt import V1Hyperopt
 from polyaxon.polytune.search_managers.hyperopt.manager import HyperoptManager
+from tests.utils import BaseTestCase
 
 
 @pytest.mark.polytune_mark
