@@ -1,6 +1,6 @@
 #!/usr/bin/python
 #
-# Copyright 2018-2020 Polyaxon, Inc.
+# Copyright 2018-2021 Polyaxon, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -14,14 +14,13 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from unittest.mock import patch
-
 import pytest
 
-from tests.utils import BaseTestCase
+from unittest.mock import patch
 
-from polyaxon.polyflow.parallel import V1RandomSearch
+from polyaxon.polyflow.matrix import V1RandomSearch
 from polyaxon.polytune.search_managers.random_search.manager import RandomSearchManager
+from tests.utils import BaseTestCase
 
 
 @pytest.mark.polytune_mark
