@@ -1,6 +1,6 @@
 #!/usr/bin/python
 #
-# Copyright 2018-2020 Polyaxon, Inc.
+# Copyright 2018-2021 Polyaxon, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -15,9 +15,8 @@
 # limitations under the License.
 import pytest
 
-from tests.utils import BaseTestCase
-
 from polyaxon.proxies.schemas.streams.base import get_base_config
+from tests.utils import BaseTestCase
 
 
 @pytest.mark.proxies_mark
@@ -35,6 +34,7 @@ error_log /polyaxon/logs/error.log warn;
 gzip                        on;
 gzip_disable                "msie6";
 gzip_types                  *;
+gzip_proxied                any;
 
 
 charset utf-8;
@@ -46,12 +46,13 @@ client_body_in_file_only clean;
 sendfile on;
 
 
-send_timeout 600;
-keepalive_timeout 600;
-uwsgi_read_timeout 600;
-uwsgi_send_timeout 600;
-client_header_timeout 600;
-proxy_read_timeout 600;
+send_timeout 650;
+keepalive_timeout 650;
+uwsgi_read_timeout 650;
+uwsgi_send_timeout 650;
+client_header_timeout 650;
+proxy_read_timeout 650;
+keepalive_requests 10000;
 
 
 location / {
@@ -63,12 +64,13 @@ location / {
     proxy_set_header Origin "";
     proxy_set_header Host $http_host;
     proxy_set_header X-Real-IP $remote_addr;
+    proxy_intercept_errors off;
 }
 
 
-error_page 500 502 503 504 /50x.html;
-error_page 401 403 /permission.html;
-error_page 404 /404.html;
+error_page 500 502 503 504 /static/errors/50x.html;
+error_page 401 403 /static/errors/permission.html;
+error_page 404 /static/errors/404.html;
 
 
 location /tmp/ {
